@@ -38,6 +38,10 @@ class Command(BaseCommand):
                 _('Company Status')),
             ('company_type', sync.CompanyTypeSynchronizer, _('Company Type')),
             ('company', sync.CompanySynchronizer, _('Company')),
+            ('contact', sync.ContactSynchronizer, _('Contact')),
+            ('contact_communication',
+                sync.ContactCommunicationSynchronizer,
+                _('Contact Communication')),
             ('location', sync.LocationSynchronizer, _('Location')),
             ('opportunity_status', sync.OpportunityStatusSynchronizer,
                 _('Opportunity Status')),
