@@ -103,6 +103,73 @@ API_BOARD_STATUS_LIST = [
 ]
 
 
+API_CONTACT_COMMUNICATION_LIST = [
+    {
+        "id": 2,
+        "contactId": 1,
+        "type": {
+            "id": 2,
+            "name": "Direct",
+        },
+        "value": "8139357100",
+        "extension": "401",
+        "defaultFlag": True,
+        "mobileGuid": "39378d37-1746-4c26-99b8-ff4faaef2590",
+        "communicationType": "Phone",
+    },
+    {
+        "id": 3,
+        "contactId": 1,
+        "type": {
+            "id": 1,
+            "name": "Email",
+        },
+        "value": "Arnie@YourCompany.com",
+        "defaultFlag": True,
+        "mobileGuid": "4e859105-2df6-4802-a57c-dd3ed4e641c6",
+        "communicationType": "Email",
+        "domain": "@YourCompany.com",
+    }
+]
+
+
+API_COMPANY_CONTACT_LIST = [
+    {
+        "id": 2,
+        "firstName": "Arnie",
+        "lastName": "Bellini",
+        "company": {
+            "id": 12,
+            "identifier": "YourCompany",
+            "name": "TestCompany",
+        },
+        "site": {
+            "id": 224,
+            "name": "Main",
+        },
+        "inactiveFlag": False,
+        "title": "CPA, MBA",
+        "marriedFlag": False,
+        "childrenFlag": False,
+        "portalSecurityLevel": 6,
+        "disablePortalLoginFlag": True,
+        "unsubscribeFlag": False,
+        "mobileGuid": "1a977037-e97d-4565-93d9-90e5e485bdc4",
+        "defaultPhoneType": "Direct",
+        "defaultPhoneNbr": "8139357100",
+        "defaultPhoneExtension": "401",
+        "defaultBillingFlag": False,
+        "defaultFlag": True,
+        "companyLocation": {
+            "id": 2,
+            "name": "Tampa Office",
+        },
+        "communicationItems": API_CONTACT_COMMUNICATION_LIST,
+        "types": [],
+    },
+]
+
+
 API_COMPANY_STATUS = {
     "id": 1,
     "name": "Active",
