@@ -22,6 +22,17 @@ def create_mock_call(method_name, return_value, side_effect=None):
     return mock_get_call, _patch
 
 
+def company_api_get_contacts(return_value):
+    method_name = 'djconnectwise.api.CompanyAPIClient.get_contacts'
+    return create_mock_call(method_name, return_value)
+
+
+def company_api_get_contact_communications(return_value):
+    method_name = 'djconnectwise.api.CompanyAPIClient.' \
+                  'get_contact_communications'
+    return create_mock_call(method_name, return_value)
+
+
 def company_info_get_company_info_call(return_value):
     method_name = 'djconnectwise.api.CompanyInfoManager.get_company_info'
     return create_mock_call(method_name, return_value)
