@@ -89,6 +89,8 @@ class DjconnectwiseSettings:
             'response_version': '2019.5',
             'sync_child_tickets': True,
             'sync_time_and_note_entries': True,
+            'keep_closed_ticket_days': 0,
+            'keep_closed_status_board_ids': 0
         }
 
         if hasattr(settings, 'DJCONNECTWISE_CONF_CALLABLE'):
